message

package
v0.0.0-...-69f33e9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2025 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the message type in the database.
	Label = "message"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldMsgID holds the string denoting the msg_id field in the database.
	FieldMsgID = "msg_id"
	// FieldDialogID holds the string denoting the dialog_id field in the database.
	FieldDialogID = "dialog_id"
	// FieldText holds the string denoting the text field in the database.
	FieldText = "text"
	// FieldTextEmbedding holds the string denoting the text_embedding field in the database.
	FieldTextEmbedding = "text_embedding"
	// FieldHasMedia holds the string denoting the has_media field in the database.
	FieldHasMedia = "has_media"
	// FieldMediaInfo holds the string denoting the media_info field in the database.
	FieldMediaInfo = "media_info"
	// FieldSentAt holds the string denoting the sent_at field in the database.
	FieldSentAt = "sent_at"
	// EdgeDialog holds the string denoting the dialog edge name in mutations.
	EdgeDialog = "dialog"
	// Table holds the table name of the message in the database.
	Table = "messages"
	// DialogTable is the table that holds the dialog relation/edge.
	DialogTable = "messages"
	// DialogInverseTable is the table name for the Dialog entity.
	// It exists in this package in order to avoid circular dependency with the "dialog" package.
	DialogInverseTable = "dialogs"
	// DialogColumn is the table column denoting the dialog relation/edge.
	DialogColumn = "dialog_id"
)

Variables

Columns holds all SQL columns for message fields.

var (
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Functions

func And

func And(predicates ...predicate.Message) predicate.Message

And groups predicates with the AND operator between them.

func DialogID

func DialogID(v int64) predicate.Message

DialogID applies equality check predicate on the "dialog_id" field. It's identical to DialogIDEQ.

func DialogIDEQ

func DialogIDEQ(v int64) predicate.Message

DialogIDEQ applies the EQ predicate on the "dialog_id" field.

func DialogIDIn

func DialogIDIn(vs ...int64) predicate.Message

DialogIDIn applies the In predicate on the "dialog_id" field.

func DialogIDNEQ

func DialogIDNEQ(v int64) predicate.Message

DialogIDNEQ applies the NEQ predicate on the "dialog_id" field.

func DialogIDNotIn

func DialogIDNotIn(vs ...int64) predicate.Message

DialogIDNotIn applies the NotIn predicate on the "dialog_id" field.

func HasDialog

func HasDialog() predicate.Message

HasDialog applies the HasEdge predicate on the "dialog" edge.

func HasDialogWith

func HasDialogWith(preds ...predicate.Dialog) predicate.Message

HasDialogWith applies the HasEdge predicate on the "dialog" edge with a given conditions (other predicates).

func HasMedia

func HasMedia(v bool) predicate.Message

HasMedia applies equality check predicate on the "has_media" field. It's identical to HasMediaEQ.

func HasMediaEQ

func HasMediaEQ(v bool) predicate.Message

HasMediaEQ applies the EQ predicate on the "has_media" field.

func HasMediaNEQ

func HasMediaNEQ(v bool) predicate.Message

HasMediaNEQ applies the NEQ predicate on the "has_media" field.

func ID

func ID(id uuid.UUID) predicate.Message

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Message

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Message

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Message

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Message

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Message

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Message

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Message

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Message

IDNotIn applies the NotIn predicate on the ID field.

func MsgID

func MsgID(v int) predicate.Message

MsgID applies equality check predicate on the "msg_id" field. It's identical to MsgIDEQ.

func MsgIDEQ

func MsgIDEQ(v int) predicate.Message

MsgIDEQ applies the EQ predicate on the "msg_id" field.

func MsgIDGT

func MsgIDGT(v int) predicate.Message

MsgIDGT applies the GT predicate on the "msg_id" field.

func MsgIDGTE

func MsgIDGTE(v int) predicate.Message

MsgIDGTE applies the GTE predicate on the "msg_id" field.

func MsgIDIn

func MsgIDIn(vs ...int) predicate.Message

MsgIDIn applies the In predicate on the "msg_id" field.

func MsgIDLT

func MsgIDLT(v int) predicate.Message

MsgIDLT applies the LT predicate on the "msg_id" field.

func MsgIDLTE

func MsgIDLTE(v int) predicate.Message

MsgIDLTE applies the LTE predicate on the "msg_id" field.

func MsgIDNEQ

func MsgIDNEQ(v int) predicate.Message

MsgIDNEQ applies the NEQ predicate on the "msg_id" field.

func MsgIDNotIn

func MsgIDNotIn(vs ...int) predicate.Message

MsgIDNotIn applies the NotIn predicate on the "msg_id" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Message) predicate.Message

Or groups predicates with the OR operator between them.

func SentAt

func SentAt(v time.Time) predicate.Message

SentAt applies equality check predicate on the "sent_at" field. It's identical to SentAtEQ.

func SentAtEQ

func SentAtEQ(v time.Time) predicate.Message

SentAtEQ applies the EQ predicate on the "sent_at" field.

func SentAtGT

func SentAtGT(v time.Time) predicate.Message

SentAtGT applies the GT predicate on the "sent_at" field.

func SentAtGTE

func SentAtGTE(v time.Time) predicate.Message

SentAtGTE applies the GTE predicate on the "sent_at" field.

func SentAtIn

func SentAtIn(vs ...time.Time) predicate.Message

SentAtIn applies the In predicate on the "sent_at" field.

func SentAtLT

func SentAtLT(v time.Time) predicate.Message

SentAtLT applies the LT predicate on the "sent_at" field.

func SentAtLTE

func SentAtLTE(v time.Time) predicate.Message

SentAtLTE applies the LTE predicate on the "sent_at" field.

func SentAtNEQ

func SentAtNEQ(v time.Time) predicate.Message

SentAtNEQ applies the NEQ predicate on the "sent_at" field.

func SentAtNotIn

func SentAtNotIn(vs ...time.Time) predicate.Message

SentAtNotIn applies the NotIn predicate on the "sent_at" field.

func Text

func Text(v string) predicate.Message

Text applies equality check predicate on the "text" field. It's identical to TextEQ.

func TextContains

func TextContains(v string) predicate.Message

TextContains applies the Contains predicate on the "text" field.

func TextContainsFold

func TextContainsFold(v string) predicate.Message

TextContainsFold applies the ContainsFold predicate on the "text" field.

func TextEQ

func TextEQ(v string) predicate.Message

TextEQ applies the EQ predicate on the "text" field.

func TextEmbedding

func TextEmbedding(v pgvector.Vector) predicate.Message

TextEmbedding applies equality check predicate on the "text_embedding" field. It's identical to TextEmbeddingEQ.

func TextEmbeddingEQ

func TextEmbeddingEQ(v pgvector.Vector) predicate.Message

TextEmbeddingEQ applies the EQ predicate on the "text_embedding" field.

func TextEmbeddingGT

func TextEmbeddingGT(v pgvector.Vector) predicate.Message

TextEmbeddingGT applies the GT predicate on the "text_embedding" field.

func TextEmbeddingGTE

func TextEmbeddingGTE(v pgvector.Vector) predicate.Message

TextEmbeddingGTE applies the GTE predicate on the "text_embedding" field.

func TextEmbeddingIn

func TextEmbeddingIn(vs ...pgvector.Vector) predicate.Message

TextEmbeddingIn applies the In predicate on the "text_embedding" field.

func TextEmbeddingIsNil

func TextEmbeddingIsNil() predicate.Message

TextEmbeddingIsNil applies the IsNil predicate on the "text_embedding" field.

func TextEmbeddingLT

func TextEmbeddingLT(v pgvector.Vector) predicate.Message

TextEmbeddingLT applies the LT predicate on the "text_embedding" field.

func TextEmbeddingLTE

func TextEmbeddingLTE(v pgvector.Vector) predicate.Message

TextEmbeddingLTE applies the LTE predicate on the "text_embedding" field.

func TextEmbeddingNEQ

func TextEmbeddingNEQ(v pgvector.Vector) predicate.Message

TextEmbeddingNEQ applies the NEQ predicate on the "text_embedding" field.

func TextEmbeddingNotIn

func TextEmbeddingNotIn(vs ...pgvector.Vector) predicate.Message

TextEmbeddingNotIn applies the NotIn predicate on the "text_embedding" field.

func TextEmbeddingNotNil

func TextEmbeddingNotNil() predicate.Message

TextEmbeddingNotNil applies the NotNil predicate on the "text_embedding" field.

func TextEqualFold

func TextEqualFold(v string) predicate.Message

TextEqualFold applies the EqualFold predicate on the "text" field.

func TextGT

func TextGT(v string) predicate.Message

TextGT applies the GT predicate on the "text" field.

func TextGTE

func TextGTE(v string) predicate.Message

TextGTE applies the GTE predicate on the "text" field.

func TextHasPrefix

func TextHasPrefix(v string) predicate.Message

TextHasPrefix applies the HasPrefix predicate on the "text" field.

func TextHasSuffix

func TextHasSuffix(v string) predicate.Message

TextHasSuffix applies the HasSuffix predicate on the "text" field.

func TextIn

func TextIn(vs ...string) predicate.Message

TextIn applies the In predicate on the "text" field.

func TextLT

func TextLT(v string) predicate.Message

TextLT applies the LT predicate on the "text" field.

func TextLTE

func TextLTE(v string) predicate.Message

TextLTE applies the LTE predicate on the "text" field.

func TextNEQ

func TextNEQ(v string) predicate.Message

TextNEQ applies the NEQ predicate on the "text" field.

func TextNotIn

func TextNotIn(vs ...string) predicate.Message

TextNotIn applies the NotIn predicate on the "text" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Message queries.

func ByDialogField

func ByDialogField(field string, opts ...sql.OrderTermOption) OrderOption

ByDialogField orders the results by dialog field.

func ByDialogID

func ByDialogID(opts ...sql.OrderTermOption) OrderOption

ByDialogID orders the results by the dialog_id field.

func ByHasMedia

func ByHasMedia(opts ...sql.OrderTermOption) OrderOption

ByHasMedia orders the results by the has_media field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByMsgID

func ByMsgID(opts ...sql.OrderTermOption) OrderOption

ByMsgID orders the results by the msg_id field.

func BySentAt

func BySentAt(opts ...sql.OrderTermOption) OrderOption

BySentAt orders the results by the sent_at field.

func ByText

func ByText(opts ...sql.OrderTermOption) OrderOption

ByText orders the results by the text field.

func ByTextEmbedding

func ByTextEmbedding(opts ...sql.OrderTermOption) OrderOption

ByTextEmbedding orders the results by the text_embedding field.

Jump to