Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Message) predicate.Message
- func DialogID(v int64) predicate.Message
- func DialogIDEQ(v int64) predicate.Message
- func DialogIDIn(vs ...int64) predicate.Message
- func DialogIDNEQ(v int64) predicate.Message
- func DialogIDNotIn(vs ...int64) predicate.Message
- func HasDialog() predicate.Message
- func HasDialogWith(preds ...predicate.Dialog) predicate.Message
- func HasMedia(v bool) predicate.Message
- func HasMediaEQ(v bool) predicate.Message
- func HasMediaNEQ(v bool) predicate.Message
- func ID(id uuid.UUID) predicate.Message
- func IDEQ(id uuid.UUID) predicate.Message
- func IDGT(id uuid.UUID) predicate.Message
- func IDGTE(id uuid.UUID) predicate.Message
- func IDIn(ids ...uuid.UUID) predicate.Message
- func IDLT(id uuid.UUID) predicate.Message
- func IDLTE(id uuid.UUID) predicate.Message
- func IDNEQ(id uuid.UUID) predicate.Message
- func IDNotIn(ids ...uuid.UUID) predicate.Message
- func MsgID(v int) predicate.Message
- func MsgIDEQ(v int) predicate.Message
- func MsgIDGT(v int) predicate.Message
- func MsgIDGTE(v int) predicate.Message
- func MsgIDIn(vs ...int) predicate.Message
- func MsgIDLT(v int) predicate.Message
- func MsgIDLTE(v int) predicate.Message
- func MsgIDNEQ(v int) predicate.Message
- func MsgIDNotIn(vs ...int) predicate.Message
- func Not(p predicate.Message) predicate.Message
- func Or(predicates ...predicate.Message) predicate.Message
- func SentAt(v time.Time) predicate.Message
- func SentAtEQ(v time.Time) predicate.Message
- func SentAtGT(v time.Time) predicate.Message
- func SentAtGTE(v time.Time) predicate.Message
- func SentAtIn(vs ...time.Time) predicate.Message
- func SentAtLT(v time.Time) predicate.Message
- func SentAtLTE(v time.Time) predicate.Message
- func SentAtNEQ(v time.Time) predicate.Message
- func SentAtNotIn(vs ...time.Time) predicate.Message
- func Text(v string) predicate.Message
- func TextContains(v string) predicate.Message
- func TextContainsFold(v string) predicate.Message
- func TextEQ(v string) predicate.Message
- func TextEmbedding(v pgvector.Vector) predicate.Message
- func TextEmbeddingEQ(v pgvector.Vector) predicate.Message
- func TextEmbeddingGT(v pgvector.Vector) predicate.Message
- func TextEmbeddingGTE(v pgvector.Vector) predicate.Message
- func TextEmbeddingIn(vs ...pgvector.Vector) predicate.Message
- func TextEmbeddingIsNil() predicate.Message
- func TextEmbeddingLT(v pgvector.Vector) predicate.Message
- func TextEmbeddingLTE(v pgvector.Vector) predicate.Message
- func TextEmbeddingNEQ(v pgvector.Vector) predicate.Message
- func TextEmbeddingNotIn(vs ...pgvector.Vector) predicate.Message
- func TextEmbeddingNotNil() predicate.Message
- func TextEqualFold(v string) predicate.Message
- func TextGT(v string) predicate.Message
- func TextGTE(v string) predicate.Message
- func TextHasPrefix(v string) predicate.Message
- func TextHasSuffix(v string) predicate.Message
- func TextIn(vs ...string) predicate.Message
- func TextLT(v string) predicate.Message
- func TextLTE(v string) predicate.Message
- func TextNEQ(v string) predicate.Message
- func TextNotIn(vs ...string) predicate.Message
- func ValidColumn(column string) bool
- type OrderOption
- func ByDialogField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByDialogID(opts ...sql.OrderTermOption) OrderOption
- func ByHasMedia(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMsgID(opts ...sql.OrderTermOption) OrderOption
- func BySentAt(opts ...sql.OrderTermOption) OrderOption
- func ByText(opts ...sql.OrderTermOption) OrderOption
- func ByTextEmbedding(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the message type in the database. Label = "message" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldMsgID holds the string denoting the msg_id field in the database. FieldMsgID = "msg_id" // FieldDialogID holds the string denoting the dialog_id field in the database. FieldDialogID = "dialog_id" // FieldText holds the string denoting the text field in the database. FieldText = "text" // FieldTextEmbedding holds the string denoting the text_embedding field in the database. FieldTextEmbedding = "text_embedding" // FieldHasMedia holds the string denoting the has_media field in the database. FieldHasMedia = "has_media" // FieldMediaInfo holds the string denoting the media_info field in the database. FieldMediaInfo = "media_info" // FieldSentAt holds the string denoting the sent_at field in the database. FieldSentAt = "sent_at" // EdgeDialog holds the string denoting the dialog edge name in mutations. EdgeDialog = "dialog" // Table holds the table name of the message in the database. Table = "messages" // DialogTable is the table that holds the dialog relation/edge. DialogTable = "messages" // DialogInverseTable is the table name for the Dialog entity. // It exists in this package in order to avoid circular dependency with the "dialog" package. DialogInverseTable = "dialogs" // DialogColumn is the table column denoting the dialog relation/edge. DialogColumn = "dialog_id" )
Variables ¶
var Columns = []string{ FieldID, FieldMsgID, FieldDialogID, FieldText, FieldTextEmbedding, FieldHasMedia, FieldMediaInfo, FieldSentAt, }
Columns holds all SQL columns for message fields.
var ( // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
Functions ¶
func DialogID ¶
DialogID applies equality check predicate on the "dialog_id" field. It's identical to DialogIDEQ.
func DialogIDEQ ¶
DialogIDEQ applies the EQ predicate on the "dialog_id" field.
func DialogIDIn ¶
DialogIDIn applies the In predicate on the "dialog_id" field.
func DialogIDNEQ ¶
DialogIDNEQ applies the NEQ predicate on the "dialog_id" field.
func DialogIDNotIn ¶
DialogIDNotIn applies the NotIn predicate on the "dialog_id" field.
func HasDialogWith ¶
HasDialogWith applies the HasEdge predicate on the "dialog" edge with a given conditions (other predicates).
func HasMedia ¶
HasMedia applies equality check predicate on the "has_media" field. It's identical to HasMediaEQ.
func HasMediaEQ ¶
HasMediaEQ applies the EQ predicate on the "has_media" field.
func HasMediaNEQ ¶
HasMediaNEQ applies the NEQ predicate on the "has_media" field.
func MsgID ¶
MsgID applies equality check predicate on the "msg_id" field. It's identical to MsgIDEQ.
func MsgIDNotIn ¶
MsgIDNotIn applies the NotIn predicate on the "msg_id" field.
func SentAt ¶
SentAt applies equality check predicate on the "sent_at" field. It's identical to SentAtEQ.
func SentAtNotIn ¶
SentAtNotIn applies the NotIn predicate on the "sent_at" field.
func TextContains ¶
TextContains applies the Contains predicate on the "text" field.
func TextContainsFold ¶
TextContainsFold applies the ContainsFold predicate on the "text" field.
func TextEmbedding ¶
TextEmbedding applies equality check predicate on the "text_embedding" field. It's identical to TextEmbeddingEQ.
func TextEmbeddingEQ ¶
TextEmbeddingEQ applies the EQ predicate on the "text_embedding" field.
func TextEmbeddingGT ¶
TextEmbeddingGT applies the GT predicate on the "text_embedding" field.
func TextEmbeddingGTE ¶
TextEmbeddingGTE applies the GTE predicate on the "text_embedding" field.
func TextEmbeddingIn ¶
TextEmbeddingIn applies the In predicate on the "text_embedding" field.
func TextEmbeddingIsNil ¶
TextEmbeddingIsNil applies the IsNil predicate on the "text_embedding" field.
func TextEmbeddingLT ¶
TextEmbeddingLT applies the LT predicate on the "text_embedding" field.
func TextEmbeddingLTE ¶
TextEmbeddingLTE applies the LTE predicate on the "text_embedding" field.
func TextEmbeddingNEQ ¶
TextEmbeddingNEQ applies the NEQ predicate on the "text_embedding" field.
func TextEmbeddingNotIn ¶
TextEmbeddingNotIn applies the NotIn predicate on the "text_embedding" field.
func TextEmbeddingNotNil ¶
TextEmbeddingNotNil applies the NotNil predicate on the "text_embedding" field.
func TextEqualFold ¶
TextEqualFold applies the EqualFold predicate on the "text" field.
func TextHasPrefix ¶
TextHasPrefix applies the HasPrefix predicate on the "text" field.
func TextHasSuffix ¶
TextHasSuffix applies the HasSuffix predicate on the "text" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Message queries.
func ByDialogField ¶
func ByDialogField(field string, opts ...sql.OrderTermOption) OrderOption
ByDialogField orders the results by dialog field.
func ByDialogID ¶
func ByDialogID(opts ...sql.OrderTermOption) OrderOption
ByDialogID orders the results by the dialog_id field.
func ByHasMedia ¶
func ByHasMedia(opts ...sql.OrderTermOption) OrderOption
ByHasMedia orders the results by the has_media field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMsgID ¶
func ByMsgID(opts ...sql.OrderTermOption) OrderOption
ByMsgID orders the results by the msg_id field.
func BySentAt ¶
func BySentAt(opts ...sql.OrderTermOption) OrderOption
BySentAt orders the results by the sent_at field.
func ByText ¶
func ByText(opts ...sql.OrderTermOption) OrderOption
ByText orders the results by the text field.
func ByTextEmbedding ¶
func ByTextEmbedding(opts ...sql.OrderTermOption) OrderOption
ByTextEmbedding orders the results by the text_embedding field.